API
===

.. automodule:: pvi

    ``pvi``
    -----------------------------------

This is the internal API reference for pvi

.. data:: pvi.__version__ :noindex:
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm
